@@ -32,8 +32,8 @@ class PendingTpLoggerEntities : public KTp::PendingLoggerEntities
 
   public:
     explicit PendingTpLoggerEntities(const Tp::AccountPtr &account,
-                                     QObject *parent = 0);
-    ~PendingTpLoggerEntities();
+                                     QObject *parent = nullptr);
+    ~PendingTpLoggerEntities() override;
 
   private Q_SLOTS:
     void entitiesRetrieved(Tpl::PendingOperation *op);
